@@ -516,15 +516,19 @@ class LocalBox(BaseBox):
                     print("Error:\n", error)
                 return CodeBoxOutput(type="error", content=error)
 
-    def upload(self, file_name: str, content: bytes) -> CodeBoxStatus:
+    def upload(
+        self, file_name: str, content: bytes, timeout: int = 900
+    ) -> CodeBoxStatus:
         os.makedirs(".codebox", exist_ok=True)
         with open(os.path.join(".codebox", file_name), "wb") as f:
             f.write(content)
 
         return CodeBoxStatus(status=f"{file_name} uploaded successfully")
 
-    async def aupload(self, file_name: str, content: bytes) -> CodeBoxStatus:
-        return await asyncio.to_thread(self.upload, file_name, content)
+    async def aupload(
+        self, file_name: str, content: bytes, timeout: int = 900
+    ) -> CodeBoxStatus:
+        return await asyncio.to_thread(self.upload, file_name, content, timeout)
 
     def download(self, file_name: str) -> CodeBoxFile:
         with open(os.path.join(".codebox", file_name), "rb") as f:
@@ -536,15 +540,17 @@ class LocalBox(BaseBox):
         return await asyncio.to_thread(self.download, file_name)
 
     def install(self, package_name: str) -> CodeBoxStatus:
-        self.run(f"!pip install -q {package_name}")
-        self.restart()
-        self.run(f"try:\n    import {package_name}\nexcept:\n    pass")
+        result = self.run(f"!pip install -q {package_name}")
+        if result.type == "error":
+            raise RuntimeError(f"Failed to install {package_name}")
+
         return CodeBoxStatus(status=f"{package_name} installed successfully")
 
     async def ainstall(self, package_name: str) -> CodeBoxStatus:
-        await self.arun(f"!pip install -q {package_name}")
-        await self.arestart()
-        await self.arun(f"try:\n    import {package_name}\nexcept:\n    pass")
+        result = await self.arun(f"!pip install -q {package_name}")
+        if result.type == "error":
+            raise RuntimeError(f"Failed to install {package_name}")
+
         return CodeBoxStatus(status=f"{package_name} installed successfully")
 
     def list_files(self) -> List[CodeBoxFile]:
